@@ -5,7 +5,8 @@ test_that("Kummer relation", {
   b <- c(9, 10)
   c <- sum(b)-sum(a)
   p <- 4
-  o1 <- mvgamma(b[2],p)*mvgamma(c,p)/mvgamma(b[2]-a[3],p)/mvgamma(c+a[3],p) *
+  o1 <-
+    mvgamma(b[2], p)*mvgamma(c, p)/mvgamma(b[2]-a[3], p)/mvgamma(c+a[3], p) *
     hypergeomPFQ(m=100, c(b[1]-a[1], b[1]-a[2], a[3]), c(b[1], c+a[3]), diag(p))
   o2 <- hypergeomPFQ(m=15, a, b, diag(p))
   expect_equal(o1, o2, tolerance = 1e-3)
@@ -14,7 +15,8 @@ test_that("Kummer relation", {
   b <- c(9i, 10)
   c <- sum(b)-sum(a)
   p <- 3
-  o1 <- mvgamma(b[2],p)*mvgamma(c,p)/mvgamma(b[2]-a[3],p)/mvgamma(c+a[3],p) *
+  o1 <-
+    mvgamma(b[2], p)*mvgamma(c, p)/mvgamma(b[2]-a[3], p)/mvgamma(c+a[3], p) *
     hypergeomPFQ(m=100, c(b[1]-a[1], b[1]-a[2], a[3]), c(b[1], c+a[3]), diag(p))
   o2 <- hypergeomPFQ(m=15, a, b, diag(p))
   expect_equal(o1, o2, tolerance = 1e-5)
